@@ -13,6 +13,7 @@ $VERSION="0.3";
 $Sofu="";
 $file="";
 $Comment="";
+$wasbinary="";
 sub import {
 	my $class=shift;
 	my $file=shift;
@@ -21,6 +22,7 @@ sub import {
 	$Config::Sofu::Sofu=Data::Sofu->new;
 	%Config::Sofu::CONFIG=$Config::Sofu::Sofu->read($file);
 	$Config::Sofu::Comment=$Config::Sofu::Sofu->comment if $Data::Sofu::VERSION ge "0.23";
+	$Config::Sofu::wasbinary=$Config::Sofu::Sofu->{BINARY} if $Config::Sofu::Sofu->{BINARY}
 	Config::Sofu->export_to_level(1, '%CONFIG',@_);
 }
 sub save {
@@ -31,7 +33,12 @@ sub save {
 	my %CONF=%main::CONFIG;
 	%CONF=@_ if @_;
 	if ($Data::Sofu::VERSION ge "0.23") {
-		$Config::Sofu::Sofu->write($Config::Sofu::file,\%CONF,$Config::Sofu::Comment);
+		if ($Config::Sofu::wasbinary) {
+			$Config::Sofu::Sofu->writeBinary($Config::Sofu::file,\%CONF,$Config::Sofu::Comment);
+		}
+		else {
+			$Config::Sofu::Sofu->write($Config::Sofu::file,\%CONF,$Config::Sofu::Comment);
+		}
 	}
 	else {
 		$Config::Sofu::Sofu->write($Config::Sofu::file,\%CONF);
@@ -39,6 +46,10 @@ sub save {
 }
 1;
 
+=head1 NAME
+
+Config::Sofu - Easy interface to configuration files in .sofu format
+
 =head1 SYNOPSIS
 
 	use vars qw/%CONFIG/; 
@@ -61,23 +72,30 @@ or
 
 =head1 SYNTAX
 
-This class exports the hash %CONFIG by default which contains all the information of the file which is given to the use statement.
+This class exports the hash %CONFIG by default which contains all the information of the file given to the use statement.
+
+=head1 DESCRIPTION
+
+This module does just one thing: It loads data from a .sofu file and puts it into %CONFIG.
 
 =head1 FUNCTIONS AND METHODS
 
+=head2 save()
 
-=head2 save
+Save the new configuration of to the same file again.
 
-Save the new configuration of to the same file again
+If the file was binary sofu it is saved again in binary sofu.
 
 =head1 BUGS
 
 The comments in the sofu-file will only be saved again if Data::Sofu >= 0.2.3 is installed.
 
+Can only read binary sofu files if Data::Sofu >= 0.2.8 is installed.
+
 =head1 SEE ALSO
 
-Data::Sofu,perl(1),L<http://sofu.sf.net>
-
-
+L<Data::Sofu>,perl(1),L<http://sofu.sf.net>
 
 =cut
+
+1;
